==> fantacalciobazar_0.3.tar.gz: fantacalciobazar/mercato.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

include("dati/head.php");

include("controlla_pass.php");
if ($pass_errata != "SI") {


echo "<center><font size=+2>Mercato</font></center>
<table align=\"center\"><tr>
<td><form method=\"post\" action=\"tab_calciatori.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"tab_calciatori\" value=\"Guarda tutti\">
i<select name=\"ruolo_guarda\">
<option value=\"tutti\">calciatori</option>
<option value=\"P\">portieri</option>
<option value=\"D\">difensori</option>
<option value=\"C\">centrocampisti</option>
<option value=\"A\">attaccanti</option>
</select>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</form></td>
<td><form method=\"post\" action=\"squadra.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"guarda_squadra\" value=\"Guarda la squadra\">
 <select name=\"nome_squadra\">
<option value=\"tutti\">di tutti</option>";
$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
$soprannome_squadra = @file("dati/squadra_$giocatore");
$soprannome_squadra = $soprannome_squadra[3];
if (!$soprannome_squadra) $soprannome_squadra = "di $giocatore";
echo "<option value=\"$giocatore\">$soprannome_squadra</option>";
next($pass);
} # fine for $num1
echo "</select>&nbsp;&nbsp;&nbsp;&nbsp;</form></td></tr><tr>
<td align=\"center\" colspan=\"2\">
<table align=\"center\" width=\"100%\"><tr>";
if ($mostra_giornate_in_mercato == "SI") {
echo "<td align=\"center\"><form method=\"post\" action=\"guarda_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"guarda_giornata\" value=\"Guarda la giornata\">
 n <select name=\"giornata\">
<option value=\"\">--</option>";
for ($num1 = "01" ; $num1 < 100 ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata = "giornata$num1";
if (is_file("dati/$giornata")) {
echo "<option value=\"giornata$num1\">$num1</option>";
} # fine if (is_dir($giornata))
else break;
} # fine for $num1
echo "</select>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</form></td>";
} # fine if ($mostra_giornate_in_mercato == "SI")
if ($num_calciatori_scambiabili > 0) {
$scambi_proposti = @file("dati/scambi.txt");
$num_scambi_proposti = count($scambi_proposti);
for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
$dati_scambio = explode(",", $scambi_proposti[$num1]);
if ($nome_utente == $dati_scambio[4]) {
$tempo_off = $dati_scambio[7];
$tempo_off = ereg_replace("
","",$tempo_off);
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti > 0) $richiesto = "SI";
} # fine if ($nome_utente == $dati_scambio[4])
} # fine for $num1
echo "<td align=\"center\"><form method=\"post\" action=\"scambi_proposti.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">";
if ($richiesto == "SI") echo "<font color=\"red\"><b>> </b></font>";
echo "<input type=\"submit\" name=\"guarda_scambi\" value=\"Proposte di scambio\">";
if ($richiesto == "SI") echo "<font color=\"red\"><b> <</b></font>";
echo "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</form></td>";
} # fine if ($num_calciatori_scambiabili > 0)
echo "<td align=\"center\"><form method=\"post\" action=\"messaggi.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"guarda_messaggi\" value=\"Messaggi\">
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</form></td>
</tr></table></td></tr></table>";


$calciatori = @file("dati/mercato.txt");
$num_calciatori = count($calciatori);

echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"#b9ccd4\">
<tr><td><font size=-2>Num.</font></td>
<td>_____________Nome_____________</td>
<td><font size=-2>Ruolo</font></td>
<td><font size=-2>Costo</font></td>
<td><font size=-1>Proprietario</font></td>
<td>__Tempo_rimasto__</td>
<td>&nbsp;</td></tr>";

$tab_comprati = "";
$soldi_spesi = 0;
$num_calciatori_posseduti = 0;
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$vecchio_proprietario = "";
$nuovo_costo = "";

$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$nome = $dati_calciatore[1];
$ruolo = $dati_calciatore[2];
$costo = $dati_calciatore[3];
$proprietario = $dati_calciatore[4];
if ($proprietario == $nome_utente) {
$soldi_spesi = $soldi_spesi + $dati_calciatore[3];
$num_calciatori_posseduti++;
} # fine if ($proprietario == $nome_utente)
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti < 0) {
$tempo_restante = "COMPRATO";
if ($nome_utente == $proprietario) 
$offri = "<a href=\"vendi.php?num_calciatore=$numero&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">vendi</a>";
else
$offri = "<font size=-2><a href=\"scambia.php?num_calciatore=$numero&altro_utente=$proprietario&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">scambia</a></font>";
$tab_comprati .= "<tr><td>$numero</td>
<td>$nome</td>
<td>$ruolo</td>
<td>$costo</td>
<td>$proprietario</td>
<td>$tempo_restante</td>
<td>$offri</td></tr>";
} # fine if ($sec_restanti < 0)
else { 
$giorni_restanti = floor($sec_restanti/86400);
$ore_restanti = floor($sec_restanti/3600) - $giorni_restanti * 24;
$minuti_restanti = floor($sec_restanti/60) - $ore_restanti * 60 - $giorni_restanti * 24 * 60;
$tempo_restante = "";
if ($giorni_restanti > 0) { $tempo_restante = "$giorni_restanti giorni "; }
if ($ore_restanti > 0) { $tempo_restante .= "$ore_restanti h. "; }
$tempo_restante .= "$minuti_restanti m.";
$offri = "<a href=\"offerta.php?num_calciatore=$numero&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">offri</a>";
$vecchio_proprietario = $dati_calciatore[6];
$nuovo_costo = $dati_calciatore[8];
if ($vecchio_proprietario) { $proprietario_mostra = "$proprietario <font size=-2>(venduto da $vecchio_proprietario)</font>"; }
else { $proprietario_mostra = $proprietario; }
if ($nuovo_costo) { $costo_mostra = $nuovo_costo; }
else { $costo_mostra = $costo; }
echo "<tr><td>$numero</td>
<td>$nome</td>
<td>$ruolo</td>
<td>$costo_mostra</td>
<td>$proprietario_mostra</td>
<td>$tempo_restante</td>
<td>$offri</td></tr>";
} # fine else if ($sec_restanti < 0)

} # fine for $num1
echo "$tab_comprati</table>";

$num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
$surplus = @file("dati/squadra_$nome_utente");
$surplus = $surplus[0];
$soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
if ($num_calciatori_comprabili <= 0 or $soldi_spendibili <= 0) { $offribile = "NO"; }
echo "<center>Soldi ancora da spendere: <b>$soldi_spendibili</b> Euro. &nbsp;&nbsp;
Numero di calciatori ancora comperabili: <b>$num_calciatori_comprabili</b>.</center>";




} # fine if ($pass_errata != "SI")

if ($pass_admin_errata == "NO") {
echo "<center>Benvenuto admin!<br>";
echo "<form method=\"post\" action=\"giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">";
for ($num1 = "01" ; $num1 < 100 ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata = "giornata$num1";
if (is_file("dati/$giornata")) {
echo "<input type=\"submit\" name=\"giornata\" value=\"$giornata\">&nbsp;";
} # fine if (is_dir($giornata))
else break;
$pulsanti++;
if ($pulsanti == 5) {
echo "<br>";
$pulsanti = 0;
} # fine if ($pulsanti == 5)
} # fine for $num1
echo "</form>
<form method=\"post\" action=\"crea_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"crea_giornata\" value=\"Crea la giornata $num1\">
</form></center>";
} # fine if ($pass_admin_errata == "NO")

include("dati/foot.php");
?>

==> fantacalciobazar_0.4.tar.gz: fantacalciobazar/mercato.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {



if ($sfondo_tab == "") $sfondo_tab = "#b9ccd4";

echo "<center><font size=+2>Mercato</font>";
if ($stato_mercato == "C") echo "<br><font size=-1>(chiuso)</font>";
if ($stato_mercato == "S") echo "<br><font size=-1>(sospeso)</font>";
echo "</center>
<table align=\"center\"><tr>
<td><form method=\"post\" action=\"tab_calciatori.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"tab_calciatori\" value=\"Guarda tutti\">
i<select name=\"ruolo_guarda\">
<option value=\"tutti\">calciatori</option>
<option value=\"P\">portieri</option>
<option value=\"D\">difensori</option>
<option value=\"C\">centrocampisti</option>
<option value=\"A\">attaccanti</option>
</select>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</form></td>
<td><form method=\"post\" action=\"squadra.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"guarda_squadra\" value=\"Guarda la squadra\">
 <select name=\"nome_squadra\">
<option value=\"tutti\">di tutti</option>";
$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
$soprannome_squadra = @file("$percorso_cartella_dati/squadra_$giocatore");
$soprannome_squadra[3] = str_replace("
","",$soprannome_squadra[3]);
$soprannome_squadra = $soprannome_squadra[3];
if (!$soprannome_squadra) $soprannome_squadra = "di $giocatore";
echo "<option value=\"$giocatore\">$soprannome_squadra</option>";
next($pass);
} # fine for $num1
echo "</select>&nbsp;&nbsp;&nbsp;&nbsp;</form></td></tr><tr>
<td align=\"center\" colspan=\"2\">
<table align=\"center\" width=\"100%\"><tr>";
if ($mostra_giornate_in_mercato == "SI") {
echo "<td align=\"center\"><form method=\"post\" action=\"guarda_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"guarda_giornata\" value=\"Guarda la giornata\">
 n <select name=\"giornata\">
<option value=\"\">--</option>";
for ($num1 = "01" ; $num1 < 100 ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata = "giornata$num1";
if (@is_file("$percorso_cartella_dati/$giornata")) {
echo "<option value=\"giornata$num1\">$num1</option>";
} # fine if (is_dir($giornata))
else break;
} # fine for $num1
echo "</select>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</form></td>";
} # fine if ($mostra_giornate_in_mercato == "SI")
if ($num_calciatori_scambiabili > 0) {
$scambi_proposti = @file("$percorso_cartella_dati/scambi.txt");
$num_scambi_proposti = count($scambi_proposti);
for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
$dati_scambio = explode(",", $scambi_proposti[$num1]);
if ($nome_utente == $dati_scambio[4]) {
$tempo_off = $dati_scambio[7];
$tempo_off = ereg_replace("
","",$tempo_off);
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti > 0) $richiesto = "SI";
} # fine if ($nome_utente == $dati_scambio[4])
} # fine for $num1
echo "<td align=\"center\"><form method=\"post\" action=\"scambi_proposti.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">";
if ($richiesto == "SI") echo "<font color=\"red\"><b>> </b></font>";
echo "<input type=\"submit\" name=\"guarda_scambi\" value=\"Proposte di scambio\">";
if ($richiesto == "SI") echo "<font color=\"red\"><b> <</b></font>";
echo "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</form></td>";
} # fine if ($num_calciatori_scambiabili > 0)
echo "<td align=\"center\"><form method=\"post\" action=\"messaggi.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"guarda_messaggi\" value=\"Messaggi\">
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</form></td>
</tr></table></td></tr></table>";


$calciatori = @file("$percorso_cartella_dati/mercato.txt");
$num_calciatori = count($calciatori);

echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
<tr><td><font size=-2>Num.</font></td>
<td>_____________Nome_____________</td>
<td><font size=-2>Ruolo</font></td>
<td><font size=-2>Costo</font></td>
<td><font size=-1>Proprietario</font></td>
<td>__Tempo_rimasto__</td>
<td>&nbsp;</td></tr>";

$tab_comprati = "";
$soldi_spesi = 0;
$num_calciatori_posseduti = 0;
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$vecchio_proprietario = "";
$nuovo_costo = "";

$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$nome = $dati_calciatore[1];
$ruolo = $dati_calciatore[2];
$costo = $dati_calciatore[3];
$proprietario = $dati_calciatore[4];
if ($proprietario == $nome_utente) {
$soldi_spesi = $soldi_spesi + $dati_calciatore[3];
$num_calciatori_posseduti++;
} # fine if ($proprietario == $nome_utente)
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti < 0) {
$tempo_restante = "COMPRATO";
if ($nome_utente == $proprietario) 
$offri = "<a href=\"vendi.php?num_calciatore=$numero&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">vendi</a>";
else
$offri = "<font size=-2><a href=\"scambia.php?num_calciatore=$numero&altro_utente=$proprietario&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">scambia</a></font>";
$tab_comprati .= "<tr><td>$numero</td>
<td>$nome</td>
<td>$ruolo</td>
<td>$costo</td>
<td>$proprietario</td>
<td>$tempo_restante</td>
<td>$offri</td></tr>";
} # fine if ($sec_restanti < 0)
else { 
$giorni_restanti = floor($sec_restanti/86400);
$ore_restanti = floor($sec_restanti/3600) - $giorni_restanti * 24;
$minuti_restanti = floor($sec_restanti/60) - $ore_restanti * 60 - $giorni_restanti * 24 * 60;
$tempo_restante = "";
if ($giorni_restanti > 0) { $tempo_restante = "$giorni_restanti giorni "; }
if ($ore_restanti > 0) { $tempo_restante .= "$ore_restanti h. "; }
$tempo_restante .= "$minuti_restanti m.";
$offri = "<a href=\"offerta.php?num_calciatore=$numero&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">offri</a>";
$vecchio_proprietario = $dati_calciatore[6];
$nuovo_costo = $dati_calciatore[8];
if ($vecchio_proprietario) { $proprietario_mostra = "$proprietario <font size=-2>(venduto da $vecchio_proprietario)</font>"; }
else { $proprietario_mostra = $proprietario; }
if ($nuovo_costo) { $costo_mostra = $nuovo_costo; }
else { $costo_mostra = $costo; }
echo "<tr><td>$numero</td>
<td>$nome</td>
<td>$ruolo</td>
<td>$costo_mostra</td>
<td>$proprietario_mostra</td>
<td>$tempo_restante</td>
<td>$offri</td></tr>";
} # fine else if ($sec_restanti < 0)

} # fine for $num1
echo "$tab_comprati</table>";

$num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
$surplus = @file("$percorso_cartella_dati/squadra_$nome_utente");
$surplus = $surplus[0];
$soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
if ($num_calciatori_comprabili <= 0 or $soldi_spendibili <= 0) { $offribile = "NO"; }
echo "<center>Soldi ancora da spendere: <b>$soldi_spendibili</b> Fanta-Euro. &nbsp;&nbsp;
Numero di calciatori ancora comperabili: <b>$num_calciatori_comprabili</b>.</center>";




} # fine if ($pass_errata != "SI")

if ($pass_admin_errata == "NO") {
echo "<center>Benvenuto admin!<br><br>
<form method=\"post\" action=\"configura.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"vai_a_configura\" value=\"Configura Fantacalciobazar\">
</form><br>";
echo "<form method=\"post\" action=\"giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">";
for ($num1 = "01" ; $num1 < 100 ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata = "giornata$num1";
if (@is_file("$percorso_cartella_dati/$giornata")) {
echo "<input type=\"submit\" name=\"giornata\" value=\"$giornata\">&nbsp;";
} # fine if (is_dir($giornata))
else break;
$pulsanti++;
if ($pulsanti == 5) {
echo "<br>";
$pulsanti = 0;
} # fine if ($pulsanti == 5)
} # fine for $num1
echo "</form>
<form method=\"post\" action=\"crea_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"crea_giornata\" value=\"Crea la giornata $num1\">
</form></center>";
} # fine if ($pass_admin_errata == "NO")

include("$percorso_cartella_dati/foot.php");
?>
